==> ejc-jlincome-impl-3.0.0-20240930.032106-242-sources.jar: com/ejianc/business/jlincome/performance/bean/ForecastDetailEntity.java <==
package com.ejianc.business.jlincome.performance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 绩效管理-销售预报-子表
 *
 * @author generator
 */
@TableName("ejc_performance_forecast_detail")
public class ForecastDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value = "pid")
    private Long pid; // 销售预报主表id
    @TableField(value = "detail_org_id")
    private Long detailOrgId; // 区域小组
    @TableField(value = "detail_org_name")
    private String detailOrgName; // 区域名称
    @TableField(value = "detail_org_code")
    private String detailOrgCode; // 区域编码
    @TableField(value = "customer_id")
    private Long customerId; // 客户单位id
    @TableField(value = "customer_name")
    private String customerName; // 客户单位名称
    @TableField(value = "detail_person_id")
    private Long detailPersonId; // 负责人id
    @TableField(value = "detail_person_name")
    private String detailPersonName; // 负责人
    @TableField(value = "sale_detail_mny")
    private BigDecimal saleDetailMny; // 预计销售
    @TableField(value = "invoice_detail_mny")
    private BigDecimal invoiceDetailMny; // 预计开票
    @TableField(value = "income_detail_mny")
    private BigDecimal incomeDetailMny; // 预计回款
    @TableField(value = "success_date")
    private Date successDate; // 完成时间
    @TableField(value = "parent_id")
    private Long parentId; // 父级id
    @TableField(value = "leaf_flag")
    private Boolean leafFlag; // 是否末级
    @TableField(value = "memo")
    private String memo; // 备注

    //树形相关字段
    @TableField(exist = false)
    private String tid;
    @TableField(exist = false)
    private String tpid;


    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }

    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }

    public Date getSuccessDate() {
        return successDate;
    }

    public void setSuccessDate(Date successDate) {
        this.successDate = successDate;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getDetailOrgId() {
        return detailOrgId;
    }

    public void setDetailOrgId(Long detailOrgId) {
        this.detailOrgId = detailOrgId;
    }

    public String getDetailOrgName() {
        return detailOrgName;
    }

    public void setDetailOrgName(String detailOrgName) {
        this.detailOrgName = detailOrgName;
    }

    public String getDetailOrgCode() {
        return detailOrgCode;
    }

    public void setDetailOrgCode(String detailOrgCode) {
        this.detailOrgCode = detailOrgCode;
    }

    public Long getDetailPersonId() {
        return detailPersonId;
    }

    public void setDetailPersonId(Long detailPersonId) {
        this.detailPersonId = detailPersonId;
    }

    public String getDetailPersonName() {
        return detailPersonName;
    }

    public void setDetailPersonName(String detailPersonName) {
        this.detailPersonName = detailPersonName;
    }

    public BigDecimal getSaleDetailMny() {
        return saleDetailMny;
    }

    public void setSaleDetailMny(BigDecimal saleDetailMny) {
        this.saleDetailMny = saleDetailMny;
    }

    public BigDecimal getInvoiceDetailMny() {
        return invoiceDetailMny;
    }

    public void setInvoiceDetailMny(BigDecimal invoiceDetailMny) {
        this.invoiceDetailMny = invoiceDetailMny;
    }

    public BigDecimal getIncomeDetailMny() {
        return incomeDetailMny;
    }

    public void setIncomeDetailMny(BigDecimal incomeDetailMny) {
        this.incomeDetailMny = incomeDetailMny;
    }
}

==> ejc-jlincome-impl-3.0.0-20241127.035837-349-sources.jar: com/ejianc/business/jlincome/performance/bean/ForecastDetailEntity.java <==
package com.ejianc.business.jlincome.performance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 绩效管理-销售预报-子表
 *
 * @author generator
 */
@TableName("ejc_performance_forecast_detail")
public class ForecastDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    @TableField(value = "pid")
    private Long pid; // 销售预报主表id
    @TableField(value = "detail_org_id")
    private Long detailOrgId; // 区域小组
    @TableField(value = "detail_org_name")
    private String detailOrgName; // 区域名称
    @TableField(value = "detail_org_code")
    private String detailOrgCode; // 区域编码
    @TableField(value = "customer_id")
    private Long customerId; // 客户单位id
    @TableField(value = "customer_name")
    private String customerName; // 客户单位名称
    @TableField(value = "detail_person_id")
    private Long detailPersonId; // 负责人id
    @TableField(value = "detail_person_name")
    private String detailPersonName; // 负责人
    @TableField(value = "sale_detail_mny")
    private BigDecimal saleDetailMny; // 预计销售
    @TableField(value = "invoice_detail_mny")
    private BigDecimal invoiceDetailMny; // 预计开票
    @TableField(value = "income_detail_mny")
    private BigDecimal incomeDetailMny; // 预计回款
    @TableField(value = "success_date")
    private Date successDate; // 完成时间
    @TableField(value = "parent_id")
    private Long parentId; // 父级id
    @TableField(value = "leaf_flag")
    private Boolean leafFlag; // 是否末级
    @TableField(value = "memo")
    private String memo; // 备注

    //树形相关字段
    @TableField(exist = false)
    private String tid;
    @TableField(exist = false)
    private String tpid;

    @TableField(value="detail_project_id")
    private Long detailProjectId; // 所属项目ID
    @TableField(value="detail_project_code")
    private String detailProjectCode; // 所属项目code
    @TableField(value="detail_project_name")
    private String detailProjectName; // 所属项目名称

    public Long getDetailProjectId() {
        return detailProjectId;
    }

    public void setDetailProjectId(Long detailProjectId) {
        this.detailProjectId = detailProjectId;
    }

    public String getDetailProjectCode() {
        return detailProjectCode;
    }

    public void setDetailProjectCode(String detailProjectCode) {
        this.detailProjectCode = detailProjectCode;
    }

    public String getDetailProjectName() {
        return detailProjectName;
    }

    public void setDetailProjectName(String detailProjectName) {
        this.detailProjectName = detailProjectName;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }

    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }

    public Date getSuccessDate() {
        return successDate;
    }

    public void setSuccessDate(Date successDate) {
        this.successDate = successDate;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public Boolean getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getDetailOrgId() {
        return detailOrgId;
    }

    public void setDetailOrgId(Long detailOrgId) {
        this.detailOrgId = detailOrgId;
    }

    public String getDetailOrgName() {
        return detailOrgName;
    }

    public void setDetailOrgName(String detailOrgName) {
        this.detailOrgName = detailOrgName;
    }

    public String getDetailOrgCode() {
        return detailOrgCode;
    }

    public void setDetailOrgCode(String detailOrgCode) {
        this.detailOrgCode = detailOrgCode;
    }

    public Long getDetailPersonId() {
        return detailPersonId;
    }

    public void setDetailPersonId(Long detailPersonId) {
        this.detailPersonId = detailPersonId;
    }

    public String getDetailPersonName() {
        return detailPersonName;
    }

    public void setDetailPersonName(String detailPersonName) {
        this.detailPersonName = detailPersonName;
    }

    public BigDecimal getSaleDetailMny() {
        return saleDetailMny;
    }

    public void setSaleDetailMny(BigDecimal saleDetailMny) {
        this.saleDetailMny = saleDetailMny;
    }

    public BigDecimal getInvoiceDetailMny() {
        return invoiceDetailMny;
    }

    public void setInvoiceDetailMny(BigDecimal invoiceDetailMny) {
        this.invoiceDetailMny = invoiceDetailMny;
    }

    public BigDecimal getIncomeDetailMny() {
        return incomeDetailMny;
    }

    public void setIncomeDetailMny(BigDecimal incomeDetailMny) {
        this.incomeDetailMny = incomeDetailMny;
    }
}
